import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Input, Output, NgModule } from '@angular/core';
import * as i1 from '@angular/platform-browser';
import * as i1$1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i3 from '@ngx-translate/core';
import { TranslateModule } from '@ngx-translate/core';

/**
 * Created by romeo on 24/10/2021.
 */
class ActionButtonTable {
    key;
    icon; // Can be Font-awesome icon(with other class if prefer) or image content '/'
    text; // if icon empty, used to display link(a tag) text.
    tooltip;
    css;
    html;
    targetData;
    target;
    displayConditionFn;
    constructor(key, text, icon, tooltip, css, html) {
        this.key = key;
        this.icon = icon || '';
        this.text = text || '';
        this.tooltip = tooltip || this.text;
        this.css = css || '';
        this.html = html || '';
        this.target = -1;
        this.displayConditionFn = data => true;
    }
    keyValue(value) {
        this.key = value;
        return this;
    }
    iconValue(value) {
        this.icon = value || '';
        return this;
    }
    textValue(value) {
        this.text = value || '';
        return this;
    }
    tooltipValue(value) {
        this.tooltip = value || '';
        return this;
    }
    cssValue(value) {
        this.css = value || '';
        return this;
    }
    htmlValue(value) {
        this.html = value || '';
        return this;
    }
    displayCondition(condition) {
        this.displayConditionFn = condition;
        return this;
    }
}

/**
 * Created by romeo on 24/10/2021.
 */
class CellData {
    value;
    researchData; // Data to use on search
    original;
    constructor(value, researchData, original) {
        this.value = value || '';
        this.researchData = researchData || this.value;
        this.original = original;
    }
    static valueOf(obj) {
        const cellData = new CellData();
        if (obj) {
            if (obj.value !== null && obj.value !== undefined) {
                cellData.value = obj.value || '';
            }
            if (obj.researchData !== null && obj.researchData !== undefined) {
                cellData.researchData = obj.researchData || cellData.value;
            }
            if (obj.original !== null && obj.original !== undefined) {
                cellData.original = obj.original;
            }
        }
        return cellData;
    }
    researchDataValue(value) {
        this.researchData = value;
        return this;
    }
}

/**
 * Created by romeo on 24/10/2021.
 */
class ColumnTable {
    title;
    nameProperty; // Name of property in data list
    display;
    width;
    customCellFn;
    constructor(title, nameProperty, display, width) {
        this.title = title;
        this.nameProperty = nameProperty || title;
        this.display = display == null ? true : display;
        this.width = width || '';
        this.customCellFn = (data, cellData) => '';
    }
    titleValue(value) {
        this.title = value;
        return this;
    }
    namePropertyValue(value) {
        this.nameProperty = value || this.title;
        return this;
    }
    displayValue(value) {
        this.display = value == null ? true : value;
        return this;
    }
    widthValue(value) {
        this.width = value || '';
        return this;
    }
    customCell(cellDefinition) {
        this.customCellFn = cellDefinition;
        return this;
    }
}

/**
 * Created by romeo on 24/10/2021.
 */
class RowTable {
    data;
    nativeElement;
    constructor(data, nativeElement) {
        this.data = data;
        this.nativeElement = nativeElement;
    }
}

class NgxAgileTableService {
    static sanitizer;
    constructor(domSanitizer) {
        NgxAgileTableService.sanitizer = domSanitizer;
    }
    static getSanitizer() {
        return NgxAgileTableService.sanitizer;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.5", ngImport: i0, type: NgxAgileTableService, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.0.5", ngImport: i0, type: NgxAgileTableService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.5", ngImport: i0, type: NgxAgileTableService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.DomSanitizer }] });

class RowData {
    originalData;
    displayData;
    constructor(originalData, displayData) {
        this.originalData = originalData;
        this.displayData = displayData;
    }
}
class Row {
    data;
    actionButtons = [];
    collapsedActionButtons = [];
}
class NgxAgileTableComponent {
    actionButtons = [];
    collapseActionButton = new ActionButtonTable('collapse', '...');
    columnSettings = [];
    data = [];
    emptyText = 'No content';
    actionButtonTitle = '';
    searchText = 'Search';
    maxSizeText = 'Max size';
    totalElementsText = 'Total Elements';
    paginationPreviousText = '<<';
    paginationNextText = '>>';
    paginationPreviousIcon = '';
    paginationNextIcon = '';
    displayGlobalSearchInput = false;
    colorVariationLineBreak = 2;
    maxActionButtonPerRow = 3;
    collapseActionButtonPosition = 'right';
    height = '';
    totalElements = 0;
    totalPages = 0;
    elementPerPage = 0;
    elementPerPageList = [];
    enableColumnFiltering = true;
    enableColumnSorting = true;
    localPagination = false;
    onClickActionButton = new EventEmitter();
    onPageChanged = new EventEmitter();
    onElementPerPageChanged = new EventEmitter();
    onGlobalSearchRequest = new EventEmitter();
    onRowDisplayed = new EventEmitter();
    pageSelected = 1;
    collapseActionButtonPositions = ['right', 'bottom'];
    pagesRangeLimit = 5;
    pageStart = 1;
    globalSearchKeywords = '';
    columnSearchKeyword = '';
    columnSearch = new ColumnTable('');
    columnSortDirectionAsc = false;
    columnSort = new ColumnTable('');
    rows = [];
    rowsToDisplay = [];
    constructor() {
    }
    ngOnInit() {
        if (!this.data) { // Value passed is null
            this.data = [];
        }
        if (this.totalElements === 0 && this.data.length !== 0) {
            this.totalElements = this.data.length;
        }
        if (!this.elementPerPage) {
            this.elementPerPage = this.data.length;
        }
        this.displayData();
    }
    formatRows() {
        const rows = [];
        let row;
        let canDisplayButton;
        for (const dt of this.data) {
            row = new Row();
            row.data = dt;
            row.actionButtons = [];
            row.collapsedActionButtons = [];
            for (const actionButton of this.actionButtons) {
                canDisplayButton = actionButton.displayConditionFn(this.data.find(d => JSON.stringify(dt) === JSON.stringify(d)));
                if (canDisplayButton) {
                    if (this.actionButtons.length <= this.maxActionButtonPerRow ||
                        row.actionButtons.length < this.maxActionButtonPerRow - 1) { // -1 for collapse button
                        row.actionButtons.push(actionButton);
                    }
                    else {
                        row.collapsedActionButtons.push(actionButton);
                    }
                }
                if (row.collapsedActionButtons.length !== 0 &&
                    (row.actionButtons.length + row.collapsedActionButtons.length) <= this.maxActionButtonPerRow) {
                    row.actionButtons = row.actionButtons.concat(row.collapsedActionButtons);
                    row.collapsedActionButtons = [];
                }
            }
            rows.push(row);
        }
        this.rows = rows;
    }
    ngOnChanges(changes) {
        if (changes.data) {
            this.data = changes.data.currentValue;
        }
        if (changes.actionButtons) {
            this.actionButtons = changes.actionButtons.currentValue;
        }
        if (changes.collapseActionButton) {
            this.collapseActionButton = changes.collapseActionButton.currentValue;
        }
        if (changes.collapseActionButtonPosition) {
            this.collapseActionButtonPosition = changes.collapseActionButtonPosition.currentValue;
        }
        if (changes.maxActionButtonPerRow) {
            this.maxActionButtonPerRow = changes.maxActionButtonPerRow.currentValue;
        }
        if (changes.totalElements) {
            this.totalElements = changes.totalElements.currentValue;
        }
        if (changes.totalPages) {
            this.totalPages = changes.totalPages.currentValue;
        }
        if (changes.elementPerPage) {
            this.elementPerPage = changes.elementPerPage.currentValue;
        }
        if (changes.height) {
            this.height = changes.height.currentValue;
        }
        if (changes.columnSettings) {
            this.columnSettings = changes.columnSettings.currentValue;
        }
        if (changes.colorVariationLineBreak) {
            this.colorVariationLineBreak = changes.colorVariationLineBreak.currentValue;
        }
        if (changes.displayGlobalSearchInput) {
            this.displayGlobalSearchInput = changes.displayGlobalSearchInput.currentValue;
        }
        if (changes.elementPerPageList) {
            this.elementPerPageList = changes.elementPerPageList.currentValue;
        }
        if (changes.localPagination) {
            this.localPagination = changes.localPagination.currentValue;
        }
        if (changes.enableColumnFiltering) {
            this.enableColumnFiltering = changes.enableColumnFiltering.currentValue;
        }
        if (changes.enableColumnSorting) {
            this.enableColumnSorting = changes.enableColumnSorting.currentValue;
        }
        if (changes.emptyText) {
            this.emptyText = changes.emptyText.currentValue;
        }
        if (changes.maxSizeText) {
            this.maxSizeText = changes.maxSizeText.currentValue;
        }
        if (changes.totalElementsText) {
            this.totalElementsText = changes.totalElementsText.currentValue;
        }
        if (this.elementPerPageList && this.elementPerPage) {
            if (this.elementPerPageList.length === 0) {
                this.elementPerPageList = [this.elementPerPage, 20, 50, 100, 200];
            }
            if (this.elementPerPageList.indexOf(this.elementPerPage) === -1) {
                this.elementPerPageList.push(this.elementPerPage);
            }
            this.elementPerPageList.sort((a, b) => a < b ? -1 : 1);
        }
        this.displayData();
    }
    displayData() {
        this.formatRows();
        if (this.localPagination) {
            this.totalPageCalculation();
            this.rowsToDisplay = this.segmentation(1);
        }
        else {
            let rows = [];
            this.rowsToDisplay = rows.concat(this.rows);
        }
    }
    totalPageCalculation(data) {
        data = data ? data : this.rows;
        if (data) {
            this.totalPages = data.length / this.elementPerPage;
            if ((data.length % this.elementPerPage) !== 0 || this.totalPages === 0) {
                this.totalPages++;
            }
        }
    }
    resetTotalPages(data) {
        this.pageSelected = 1;
        this.pageStart = 1;
        if (this.localPagination) {
            this.totalPageCalculation(data);
        }
    }
    segmentation(page, data) {
        data = data ? data : this.rows;
        if (data) {
            if (this.totalPages === 0) {
                return data;
            }
            else {
                if (page === 1) {
                    return data.slice(0, this.elementPerPage);
                }
                else if (data.length >= this.elementPerPage * page) {
                    return data.slice((page - 1) * this.elementPerPage, page * this.elementPerPage);
                }
                else {
                    return data.slice((page - 1) * this.elementPerPage, this.rows.length);
                }
            }
        }
        return [];
    }
    pages() {
        const result = [];
        const presumePageEnd = this.pageStart + this.pagesRangeLimit;
        const limit = presumePageEnd <= this.totalPages ? presumePageEnd - 1 : this.totalPages;
        for (let i = this.pageStart; i <= limit; i++) {
            result.push(i);
        }
        return result;
    }
    onActionButtonClicked(button, index) {
        if (!this.collapseActionButton || this.collapseActionButton.key !== button.key) {
            button.targetData = this.rowsToDisplay[index].data;
            button.target = this.rows.findIndex(r => JSON.stringify(button.targetData) === JSON.stringify(r.data));
            this.onClickActionButton.emit(button);
        }
    }
    globalSearchRequest() {
        this.onGlobalSearchRequest.emit(this.globalSearchKeywords);
    }
    onPageChange(page) {
        if (this.localPagination) {
            if (this.columnSearchKeyword && this.columnSearchKeyword !== '') {
                this.filterTable(this.columnSearch, this.columnSearchKeyword, page);
            }
            else if (this.columnSort) {
                this.sortDataDisplay(this.columnSort, this.columnSortDirectionAsc, page);
            }
            else {
                this.rowsToDisplay = this.segmentation(page);
            }
        }
        else {
            this.onPageChanged.emit(page);
        }
        this.pageSelected = page;
    }
    onElementPerPageChange() {
        if (this.localPagination) {
            if (this.columnSearchKeyword && this.columnSearchKeyword !== '') {
                this.filterTable(this.columnSearch, this.columnSearchKeyword, 1);
            }
            else if (this.columnSort) {
                this.sortDataDisplay(this.columnSort, this.columnSortDirectionAsc, 1);
            }
            else {
                this.resetTotalPages();
                this.rowsToDisplay = this.segmentation(1);
            }
        }
        else {
            this.onElementPerPageChanged.emit(this.elementPerPage);
        }
    }
    filterTable(columnTable, keyword, page) {
        let searchResults;
        if (keyword && keyword !== '') {
            searchResults = this.rows.filter(r => (this.cellDataValue(r.data, columnTable)
                .researchData + '').toLowerCase().includes(keyword.toLowerCase()));
        }
        else {
            searchResults = this.rows;
        }
        this.rowsToDisplay = this.segmentation(page ? page : 1, searchResults);
        this.resetTotalPages(searchResults);
        this.columnSearchKeyword = keyword;
        this.columnSearch = columnTable;
    }
    sortDataDisplay(columnTable, ascFiltering, page) {
        let searchResults;
        if (ascFiltering) {
            searchResults = this.rows.sort((a, b) => {
                let value = this.cellDataValue(a.data, columnTable).researchData;
                let value2 = this.cellDataValue(b.data, columnTable).researchData;
                value = parseFloat(value) ? parseFloat(value) : value;
                value2 = parseFloat(value2) ? parseFloat(value2) : value2;
                if (value < value2) {
                    return 1;
                }
                if (value > value2) {
                    return -1;
                }
                return 0;
            });
        }
        else {
            searchResults = this.rows.sort((a, b) => {
                let value = this.cellDataValue(a.data, columnTable).researchData;
                let value2 = this.cellDataValue(b.data, columnTable).researchData;
                value = parseFloat(value) ? parseFloat(value) : value;
                value2 = parseFloat(value2) ? parseFloat(value2) : value2;
                if (value > value2) {
                    return 1;
                }
                if ((value < value2)) {
                    return -1;
                }
                return 0;
            });
        }
        this.rowsToDisplay = this.segmentation(page ? page : 1, searchResults);
        this.resetTotalPages(searchResults);
        this.columnSortDirectionAsc = ascFiltering;
        this.columnSort = columnTable;
    }
    sortByColumn(attr, sortColumnDirection) {
        this.sortDataDisplay(attr, sortColumnDirection.checked);
        sortColumnDirection.checked = !sortColumnDirection.checked;
    }
    nextPages() {
        if (this.pageStart + this.pagesRangeLimit - 1 < this.totalPages) {
            this.pageStart += this.pagesRangeLimit;
        }
    }
    previousPages() {
        if (this.pageStart > this.pagesRangeLimit) {
            this.pageStart -= this.pagesRangeLimit;
        }
    }
    tableDataTitleAttribute(data, columnTable) {
        const value = '' + this.cellDataValue(data, columnTable).value;
        if (value.includes('<') && value.includes('>')) {
            return '';
        }
        else {
            return value;
        }
    }
    columnValue(data, columnProperty, sanitize) {
        let value;
        if (columnProperty.includes('.')) {
            let desiredValue = JSON.parse(JSON.stringify(data));
            columnProperty.split('.').forEach((element) => {
                if (element.includes('[') && element.includes(']')) {
                    const openHookIndex = element.indexOf('[');
                    const closeHookIndex = element.indexOf(']');
                    desiredValue = desiredValue[element.substring(0, openHookIndex)][parseInt(element.substring(openHookIndex + 1, closeHookIndex), 10)];
                }
                else if (desiredValue) {
                    desiredValue = desiredValue[element];
                }
            });
            value = desiredValue;
        }
        else {
            value = data[columnProperty];
        }
        if (sanitize !== false) {
            return this.sanitize(value);
        }
        else {
            return (value !== null && value !== undefined) ? value : '';
        }
    }
    cellDataValue(data, columnTable) {
        const originalValue = this.columnValue(data, columnTable.nameProperty, false);
        const customCellData = columnTable.customCellFn(originalValue, data);
        let cellData;
        if (customCellData) {
            if (customCellData.value) {
                cellData = CellData.valueOf(customCellData);
            }
            else if ((customCellData + '').length !== 0) {
                if ((originalValue + '').length !== 0) {
                    cellData = new CellData((customCellData + ''), originalValue);
                }
                else {
                    cellData = new CellData((customCellData + '')); // For custom cell who don't have original property value
                }
            }
            else {
                cellData = new CellData();
            }
        }
        else {
            cellData = new CellData(originalValue);
        }
        cellData.original = originalValue;
        return cellData;
    }
    columnDisplayValue(data, columnTable) {
        const cellData = this.cellDataValue(data, columnTable);
        if (cellData.value.length !== 0) { // If not default value : Default value returned by customCellFn() is empty string
            return this.sanitize(cellData.value);
        }
        else {
            return cellData.original;
        }
    }
    sanitize(value) {
        return value ? NgxAgileTableService.getSanitizer().bypassSecurityTrustHtml(value) : '<span></span>';
    }
    displayButton(button, index) {
        return button.displayConditionFn(this.rows.find(d => JSON.stringify(this.rowsToDisplay[index].data) === JSON.stringify(d.data)));
    }
    getCollapsePosition() {
        if (this.collapseActionButtonPositions.indexOf(this.collapseActionButtonPosition) !== -1) {
            return 'collapse-' + this.collapseActionButtonPosition;
        }
        else {
            return 'collapse-' + this.collapseActionButtonPositions[0];
        }
    }
    getActionButtonToDisplay(data) {
        const row = this.rows.find(row => row.data === data);
        return row.actionButtons;
    }
    getActionButtonToCollapse(data) {
        const row = this.rows.find(row => row.data === data);
        return row.collapsedActionButtons;
    }
    rowDisplayed(data, nativeElement) {
        this.onRowDisplayed.emit(new RowTable(data, nativeElement));
        return '';
    }
    getClass(actionButton) {
        return actionButton.css.length != 0 && !actionButton.css.includes(':') ? actionButton.css : '';
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.5", ngImport: i0, type: NgxAgileTableComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.5", type: NgxAgileTableComponent, isStandalone: false, selector: "ngx-table", inputs: { actionButtons: "actionButtons", collapseActionButton: "collapseActionButton", columnSettings: "columnSettings", data: "data", emptyText: "emptyText", actionButtonTitle: "actionButtonTitle", searchText: "searchText", maxSizeText: "maxSizeText", totalElementsText: "totalElementsText", paginationPreviousText: "paginationPreviousText", paginationNextText: "paginationNextText", paginationPreviousIcon: "paginationPreviousIcon", paginationNextIcon: "paginationNextIcon", displayGlobalSearchInput: "displayGlobalSearchInput", colorVariationLineBreak: "colorVariationLineBreak", maxActionButtonPerRow: "maxActionButtonPerRow", collapseActionButtonPosition: "collapseActionButtonPosition", height: "height", totalElements: "totalElements", totalPages: "totalPages", elementPerPage: "elementPerPage", elementPerPageList: "elementPerPageList", enableColumnFiltering: "enableColumnFiltering", enableColumnSorting: "enableColumnSorting", localPagination: "localPagination" }, outputs: { onClickActionButton: "onClickActionButton", onPageChanged: "onPageChanged", onElementPerPageChanged: "onElementPerPageChanged", onGlobalSearchRequest: "onGlobalSearchRequest", onRowDisplayed: "onRowDisplayed" }, usesOnChanges: true, ngImport: i0, template: "<div class=\"ngx-table\">\r\n  <div class=\"flex-end mt-3 mb-2\">\r\n    <input *ngIf=\"displayGlobalSearchInput\" id=\"search\" type=\"text\"\r\n           [(ngModel)]=\"globalSearchKeywords\" placeholder=\"{{searchText | translate}}\"\r\n           (keyup.enter)=\"globalSearchRequest()\">\r\n  </div>\r\n\r\n  <div>\r\n    <div>\r\n      <div [ngClass]=\"actionButtons && actionButtons.length != 0 ? 'responsive' : ''\">\r\n\r\n        <table class=\"table-border table-hover\" *ngIf=\"columnSettings\">\r\n\r\n          <thead>\r\n\r\n          <th *ngIf=\"actionButtons && actionButtons.length != 0\">\r\n            {{actionButtonTitle | translate}}\r\n          </th>\r\n          <ng-container *ngFor=\"let column of columnSettings; let i=index\">\r\n            <th *ngIf=\"column.display\" [ngStyle]=\"column.width ? {'width': column.width} : {}\">\r\n              <div class=\"w-100 text-center\"\r\n                   title=\"{{column.title | translate}}\">\r\n                <input class=\"column-direction\" #sortColumnDirection type=\"checkbox\" hidden/>\r\n                <strong *ngIf=\"!enableColumnSorting\">{{column.title | translate}}</strong>\r\n                <strong *ngIf=\"enableColumnSorting\" class=\"sort\"\r\n                        (click)=\"sortByColumn(column, sortColumnDirection)\">\r\n                  {{column.title | translate}}\r\n                </strong>\r\n              </div>\r\n              <input *ngIf=\"enableColumnFiltering\" class=\"column-key-search\" #filterKeyword class=\"table-input\"\r\n                     type=\"text\"\r\n                     placeholder=\"{{column.title | translate}}\"\r\n                     (keyup)=\"filterTable(column, filterKeyword.value)\"/>\r\n            </th>\r\n          </ng-container>\r\n          </thead>\r\n          <tbody [ngStyle]=\"height.length != 0 ? {'max-height': height} : {}\">\r\n          <tr *ngFor=\"let row of rowsToDisplay; let i=index\"\r\n              [ngClass]=\"colorVariationLineBreak !== 0 && (i + 1) % colorVariationLineBreak == 0 ? 'table-mark' : ''\" #nativeElement>\r\n            {{ rowDisplayed(row.data, nativeElement)}}\r\n\r\n            <td *ngIf=\"actionButtons && actionButtons.length != 0\">\r\n              <div class=\"flex-center\">\r\n                <ng-container *ngFor=\"let actionButton of row.actionButtons\">\r\n                  <div class=\"action-button action-button-margin\" title=\"{{actionButton.tooltip | translate}}\"\r\n                       (click)=\"onActionButtonClicked(actionButton, i)\">\r\n                    <div \r\n                    class=\"{{getClass(actionButton)}}\"\r\n                    *ngIf=\"actionButton.html.length != 0\" [innerHtml]=\"sanitize(actionButton.html)\"></div>\r\n\r\n                    <ng-container *ngIf=\"actionButton.html.length == 0 && actionButton.icon.length != 0\">\r\n                      <img  class=\"{{getClass(actionButton)}}\" *ngIf=\"actionButton.icon.includes('/')\" [src]=\"actionButton.icon\"\r\n                           alt=\"{{actionButton.tooltip | translate}}\">\r\n                      <i *ngIf=\"!actionButton.icon.includes('/')\" class=\"{{  getClass(actionButton)  + ' ' + actionButton.icon}}\"></i>\r\n                    </ng-container>\r\n\r\n                    <a  class=\"{{getClass(actionButton)}}\" *ngIf=\"actionButton.html.length == 0 && actionButton.icon.length == 0\">\r\n                      {{actionButton.text | translate}}\r\n                    </a>\r\n\r\n                  </div>\r\n                </ng-container>\r\n                <ng-container *ngIf=\"row.collapsedActionButtons.length !== 0\">\r\n                  <div  class=\"action-button action-button-margin\" title=\"{{collapseActionButton.tooltip | translate}}\">\r\n                    <ul class=\"collapse-action-button\">\r\n                      <li>\r\n                        <div \r\n                         *ngIf=\"collapseActionButton.html.length != 0\" [innerHtml]=\"sanitize(collapseActionButton.html)\"></div>\r\n\r\n                        <ng-container *ngIf=\"collapseActionButton.html.length == 0 && collapseActionButton.icon.length != 0\">\r\n                          <img  *ngIf=\"collapseActionButton.icon.includes('/')\" [src]=\"collapseActionButton.icon\"\r\n                               alt=\"{{collapseActionButton.tooltip | translate}}\">\r\n                          <i *ngIf=\"!collapseActionButton.icon.includes('/')\" class=\"{{collapseActionButton.icon}}\"></i>\r\n                        </ng-container>\r\n\r\n                        <a *ngIf=\"collapseActionButton.html.length == 0 && collapseActionButton.icon.length == 0\">\r\n                          {{collapseActionButton.text | translate}}\r\n                        </a>\r\n                        <ul class=\"collapse-container {{ getCollapsePosition() }}\">\r\n                          <li *ngFor=\"let collapsedButton of row.collapsedActionButtons\">\r\n                            <div \r\n                               class=\"{{getClass(collapsedButton)}}\"\r\n                               class=\"collapse-button\" title=\"{{collapsedButton.tooltip | translate}}\"\r\n                                 (click)=\"onActionButtonClicked(collapsedButton, i)\">\r\n                              <div  class=\"{{getClass(collapsedButton)}}\" *ngIf=\"collapsedButton.html.length != 0\" [innerHtml]=\"sanitize(collapsedButton.html)\"></div>\r\n\r\n                              <ng-container *ngIf=\"collapsedButton.html.length == 0 && collapsedButton.icon.length != 0\">\r\n                                <img *ngIf=\"collapsedButton.icon.includes('/')\" [src]=\"collapsedButton.icon\"\r\n                                     alt=\"{{collapsedButton.tooltip | translate}}\">\r\n                                <i *ngIf=\"!collapsedButton.icon.includes('/')\" class=\"{{  getClass(collapsedButton)  + ' ' + collapsedButton.icon}}\"></i>\r\n                              </ng-container>\r\n\r\n                              <a class=\"{{getClass(collapsedButton)}}\" *ngIf=\"collapsedButton.html.length == 0 && collapsedButton.icon.length == 0\">{{collapsedButton.text | translate}}</a>\r\n\r\n                            </div>\r\n                          </li>\r\n                        </ul>\r\n                      </li>\r\n                    </ul>\r\n                  </div>\r\n                </ng-container>\r\n              </div>\r\n            </td>\r\n\r\n            <ng-container *ngFor=\"let column of columnSettings; let i=index\">\r\n              <td *ngIf=\"column.display\"\r\n                  title=\"{{tableDataTitleAttribute(row.data,column)}}\">\r\n                <div class=\"cell-content\" [innerHtml]=\"columnDisplayValue(row.data,column)\"></div>\r\n              </td>\r\n            </ng-container>\r\n          </tr>\r\n          <tr *ngIf=\"rowsToDisplay.length === 0\" class=\"table-no-content\">\r\n            <td [attr.colspan]=\"actionButtons && actionButtons.length != 0 ? columnSettings.length + 1 : columnSettings.length\">\r\n              {{emptyText | translate}}\r\n            </td>\r\n          </tr>\r\n          </tbody>\r\n        </table>\r\n      </div>\r\n    </div>\r\n    <div class=\"table-footer\">\r\n      <div class=\"flex-between m-3\"\r\n           *ngIf=\"totalPages && totalElements &&  elementPerPageList &&  elementPerPageList.length !=0 && totalElements > elementPerPageList[0]\">\r\n        <div *ngIf=\"totalElementsText.length !== 0\">\r\n          {{totalElementsText | translate}}: {{rowsToDisplay.length !== 0 ? (rowsToDisplay.length + '/' + totalElements) : 0}}\r\n        </div>\r\n        <div class=\"flex mt-2 mb-2\">\r\n          <div class=\"mr-1 size\" *ngIf=\"maxSizeText.length !== 0\">{{maxSizeText | translate}}:</div>\r\n          <select [(ngModel)]=\"elementPerPage\" (change)=\"onElementPerPageChange()\">\r\n            <option *ngFor=\"let element of elementPerPageList\">{{element}}</option>\r\n          </select>\r\n          <nav>\r\n            <ul class=\"table-pagination justify-content-center\">\r\n              <li class=\"table-page-item\" [ngClass]=\"pageStart <= pagesRangeLimit ? 'disabled' : ''\">\r\n                <a class=\"table-page-link\" (click)=\"previousPages()\">\r\n                  <ng-container *ngIf=\"paginationPreviousIcon.length !== 0\">\r\n                    <img *ngIf=\"paginationPreviousIcon.includes('/')\" [src]=\"paginationPreviousIcon\">\r\n                    <i *ngIf=\"!paginationPreviousIcon.includes('/')\" class=\"{{paginationPreviousIcon}}\"></i>\r\n                  </ng-container>\r\n                  <ng-container *ngIf=\"paginationPreviousIcon.length === 0\">\r\n                    {{paginationPreviousText | translate}}\r\n                  </ng-container>\r\n                </a>\r\n              </li>\r\n              <li class=\"table-page-item\" *ngFor=\"let page of pages()\"\r\n                  [ngClass]=\"page == pageSelected ? 'active' : ''\">\r\n                <a class=\"table-page-link\" (click)=\"onPageChange(page)\">{{page}}</a>\r\n              </li>\r\n              <li class=\"table-page-item\" [ngClass]=\"pageStart + pagesRangeLimit - 1 >= totalPages ? 'disabled' : ''\">\r\n                <a class=\"table-page-link\" (click)=\"nextPages()\">\r\n                  <ng-container *ngIf=\"paginationNextIcon.length !== 0\">\r\n                    <img *ngIf=\"paginationNextIcon.includes('/')\" [src]=\"paginationNextIcon\">\r\n                    <i *ngIf=\"!paginationNextIcon.includes('/')\" class=\"{{paginationNextIcon}}\"></i>\r\n                  </ng-container>\r\n                  <ng-container *ngIf=\"paginationNextIcon.length === 0\">\r\n                    {{paginationNextText | translate}}\r\n                  </ng-container>\r\n                </a>\r\n              </li>\r\n            </ul>\r\n          </nav>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <div style=\"margin: 0; opacity: 0;height: 0;width: 0;\">Built with love by Klaus Laghom and Romeo Njinang</div>\r\n</div>\r\n", styles: [".ngx-table .flex,.ngx-table .flex-between,.ngx-table .flex-end,.ngx-table .flex-center{display:flex}.ngx-table .flex-between{justify-content:space-between}.ngx-table .flex-end{justify-content:flex-end}.ngx-table .flex-center{justify-content:center}.ngx-table .table-hover tbody tr:hover{background-color:#faf5ff}.ngx-table .table-input{width:95%;line-height:normal;padding:0 0 0 2px;font-weight:400;height:30px;margin-top:4px}.ngx-table .table-mark{background-color:#faf5ff}.ngx-table .table-border th,.ngx-table .table-border td{border:1px solid #dee2e6}.ngx-table .responsive{display:block;width:100%;overflow-x:auto}.ngx-table a{color:#1e6bb8;text-decoration:none}.ngx-table a:hover{text-decoration:underline;cursor:pointer}.ngx-table .action-button-margin{margin:0 .25rem}.ngx-table .action-button i:hover,.ngx-table .action-button img:hover,.ngx-table .action-button a:hover{opacity:.7;cursor:pointer}.ngx-table .action-button i{font-size:19px;padding:5px;color:#002e68}.ngx-table .action-button img{width:20px;height:20px;border-radius:30px;padding:6px}.ngx-table .collapse-action-button,.ngx-table .collapse-container{list-style-type:none;padding:0;margin:0}.ngx-table .collapse-action-button li .collapse-button{padding:7px;display:block}.ngx-table .collapse-action-button .collapse-container{display:none}.ngx-table .collapse-container{position:absolute;background-color:#fff;border:1px solid rgba(0,0,0,.15);border-radius:.25rem}.ngx-table .collapse-action-button li:hover .collapse-right{display:flex!important}.ngx-table .collapse-action-button li:hover .collapse-bottom{display:block!important}.ngx-table .collapse-right{max-width:20rem;overflow-x:auto;margin-top:-1.3rem}.ngx-table .collapse-bottom{max-height:20rem;overflow-y:auto;margin-top:-1.3rem}.ngx-table .p-1{padding:.25rem!important}.ngx-table .p-2{padding:.5rem!important}.ngx-table .p-3{padding:1rem!important}.ngx-table .m-1{margin:.25rem!important}.ngx-table .m-2{margin:.5rem!important}.ngx-table .m-3{margin:1rem!important}.ngx-table .mb-2{margin-bottom:.5rem!important}.ngx-table .mt-2{margin-right:.5rem!important}.ngx-table .mr-2{margin-top:.5rem!important}.ngx-table .ml-3{margin-left:1rem!important}.ngx-table .mr-1{margin-right:.25rem!important}.ngx-table .sort{cursor:pointer}.ngx-table .sort:hover{text-decoration:underline;opacity:.8}#search{max-width:50%}table thead th{position:-webkit-sticky;position:sticky;top:0;z-index:2;vertical-align:bottom;border:1px solid #dee2e6;border-bottom:2px solid #dee2e6;font-size:.875em;font-weight:700;background-color:#dee2e6;padding:.5em 1em;color:#000}table td .cell-content{max-width:250px;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;padding:.5em 1em}table td .action-button{padding:.5rem 0rem}table tr{color:#2d2d2d;font-weight:700}table{background-color:#fff;margin-bottom:0;border-collapse:collapse;width:100%}table thead tr{color:#2d2d2d;background-color:#dee0e4;font-weight:700}table th,table td{vertical-align:top;border-top:1px solid #dee2e6}td{font-weight:400;font-size:14px}.table-pagination{display:flex;padding-left:0;list-style:none;border-radius:.25rem;margin:0}.table-page-link{position:relative;display:block;padding:.25rem .5rem;margin-left:-1px;line-height:1.25;background-color:#fff;border:1px solid #dee2e6}.table-page-item .table-page-link{cursor:pointer}.table-page-item.active .table-page-link{background-color:#dee2e6;border-color:#dee2e6}.table-pagination .disabled{opacity:.5;cursor:auto}.size{min-width:100px;text-align:end;margin-top:6px}.table-footer select{margin:0 .5rem 0 .25rem}@media (max-width: 500px){.size{text-align:start}.table-footer .flex,.table-footer .flex-between{display:block!important}.table-footer nav{overflow:auto}.table-footer select{margin-bottom:1rem;margin-top:1rem}}\n"], dependencies: [{ kind: "directive", type: i1$1.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1$1.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$1.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i1$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "pipe", type: i3.TranslatePipe, name: "translate" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.5", ngImport: i0, type: NgxAgileTableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-table', standalone: false, template: "<div class=\"ngx-table\">\r\n  <div class=\"flex-end mt-3 mb-2\">\r\n    <input *ngIf=\"displayGlobalSearchInput\" id=\"search\" type=\"text\"\r\n           [(ngModel)]=\"globalSearchKeywords\" placeholder=\"{{searchText | translate}}\"\r\n           (keyup.enter)=\"globalSearchRequest()\">\r\n  </div>\r\n\r\n  <div>\r\n    <div>\r\n      <div [ngClass]=\"actionButtons && actionButtons.length != 0 ? 'responsive' : ''\">\r\n\r\n        <table class=\"table-border table-hover\" *ngIf=\"columnSettings\">\r\n\r\n          <thead>\r\n\r\n          <th *ngIf=\"actionButtons && actionButtons.length != 0\">\r\n            {{actionButtonTitle | translate}}\r\n          </th>\r\n          <ng-container *ngFor=\"let column of columnSettings; let i=index\">\r\n            <th *ngIf=\"column.display\" [ngStyle]=\"column.width ? {'width': column.width} : {}\">\r\n              <div class=\"w-100 text-center\"\r\n                   title=\"{{column.title | translate}}\">\r\n                <input class=\"column-direction\" #sortColumnDirection type=\"checkbox\" hidden/>\r\n                <strong *ngIf=\"!enableColumnSorting\">{{column.title | translate}}</strong>\r\n                <strong *ngIf=\"enableColumnSorting\" class=\"sort\"\r\n                        (click)=\"sortByColumn(column, sortColumnDirection)\">\r\n                  {{column.title | translate}}\r\n                </strong>\r\n              </div>\r\n              <input *ngIf=\"enableColumnFiltering\" class=\"column-key-search\" #filterKeyword class=\"table-input\"\r\n                     type=\"text\"\r\n                     placeholder=\"{{column.title | translate}}\"\r\n                     (keyup)=\"filterTable(column, filterKeyword.value)\"/>\r\n            </th>\r\n          </ng-container>\r\n          </thead>\r\n          <tbody [ngStyle]=\"height.length != 0 ? {'max-height': height} : {}\">\r\n          <tr *ngFor=\"let row of rowsToDisplay; let i=index\"\r\n              [ngClass]=\"colorVariationLineBreak !== 0 && (i + 1) % colorVariationLineBreak == 0 ? 'table-mark' : ''\" #nativeElement>\r\n            {{ rowDisplayed(row.data, nativeElement)}}\r\n\r\n            <td *ngIf=\"actionButtons && actionButtons.length != 0\">\r\n              <div class=\"flex-center\">\r\n                <ng-container *ngFor=\"let actionButton of row.actionButtons\">\r\n                  <div class=\"action-button action-button-margin\" title=\"{{actionButton.tooltip | translate}}\"\r\n                       (click)=\"onActionButtonClicked(actionButton, i)\">\r\n                    <div \r\n                    class=\"{{getClass(actionButton)}}\"\r\n                    *ngIf=\"actionButton.html.length != 0\" [innerHtml]=\"sanitize(actionButton.html)\"></div>\r\n\r\n                    <ng-container *ngIf=\"actionButton.html.length == 0 && actionButton.icon.length != 0\">\r\n                      <img  class=\"{{getClass(actionButton)}}\" *ngIf=\"actionButton.icon.includes('/')\" [src]=\"actionButton.icon\"\r\n                           alt=\"{{actionButton.tooltip | translate}}\">\r\n                      <i *ngIf=\"!actionButton.icon.includes('/')\" class=\"{{  getClass(actionButton)  + ' ' + actionButton.icon}}\"></i>\r\n                    </ng-container>\r\n\r\n                    <a  class=\"{{getClass(actionButton)}}\" *ngIf=\"actionButton.html.length == 0 && actionButton.icon.length == 0\">\r\n                      {{actionButton.text | translate}}\r\n                    </a>\r\n\r\n                  </div>\r\n                </ng-container>\r\n                <ng-container *ngIf=\"row.collapsedActionButtons.length !== 0\">\r\n                  <div  class=\"action-button action-button-margin\" title=\"{{collapseActionButton.tooltip | translate}}\">\r\n                    <ul class=\"collapse-action-button\">\r\n                      <li>\r\n                        <div \r\n                         *ngIf=\"collapseActionButton.html.length != 0\" [innerHtml]=\"sanitize(collapseActionButton.html)\"></div>\r\n\r\n                        <ng-container *ngIf=\"collapseActionButton.html.length == 0 && collapseActionButton.icon.length != 0\">\r\n                          <img  *ngIf=\"collapseActionButton.icon.includes('/')\" [src]=\"collapseActionButton.icon\"\r\n                               alt=\"{{collapseActionButton.tooltip | translate}}\">\r\n                          <i *ngIf=\"!collapseActionButton.icon.includes('/')\" class=\"{{collapseActionButton.icon}}\"></i>\r\n                        </ng-container>\r\n\r\n                        <a *ngIf=\"collapseActionButton.html.length == 0 && collapseActionButton.icon.length == 0\">\r\n                          {{collapseActionButton.text | translate}}\r\n                        </a>\r\n                        <ul class=\"collapse-container {{ getCollapsePosition() }}\">\r\n                          <li *ngFor=\"let collapsedButton of row.collapsedActionButtons\">\r\n                            <div \r\n                               class=\"{{getClass(collapsedButton)}}\"\r\n                               class=\"collapse-button\" title=\"{{collapsedButton.tooltip | translate}}\"\r\n                                 (click)=\"onActionButtonClicked(collapsedButton, i)\">\r\n                              <div  class=\"{{getClass(collapsedButton)}}\" *ngIf=\"collapsedButton.html.length != 0\" [innerHtml]=\"sanitize(collapsedButton.html)\"></div>\r\n\r\n                              <ng-container *ngIf=\"collapsedButton.html.length == 0 && collapsedButton.icon.length != 0\">\r\n                                <img *ngIf=\"collapsedButton.icon.includes('/')\" [src]=\"collapsedButton.icon\"\r\n                                     alt=\"{{collapsedButton.tooltip | translate}}\">\r\n                                <i *ngIf=\"!collapsedButton.icon.includes('/')\" class=\"{{  getClass(collapsedButton)  + ' ' + collapsedButton.icon}}\"></i>\r\n                              </ng-container>\r\n\r\n                              <a class=\"{{getClass(collapsedButton)}}\" *ngIf=\"collapsedButton.html.length == 0 && collapsedButton.icon.length == 0\">{{collapsedButton.text | translate}}</a>\r\n\r\n                            </div>\r\n                          </li>\r\n                        </ul>\r\n                      </li>\r\n                    </ul>\r\n                  </div>\r\n                </ng-container>\r\n              </div>\r\n            </td>\r\n\r\n            <ng-container *ngFor=\"let column of columnSettings; let i=index\">\r\n              <td *ngIf=\"column.display\"\r\n                  title=\"{{tableDataTitleAttribute(row.data,column)}}\">\r\n                <div class=\"cell-content\" [innerHtml]=\"columnDisplayValue(row.data,column)\"></div>\r\n              </td>\r\n            </ng-container>\r\n          </tr>\r\n          <tr *ngIf=\"rowsToDisplay.length === 0\" class=\"table-no-content\">\r\n            <td [attr.colspan]=\"actionButtons && actionButtons.length != 0 ? columnSettings.length + 1 : columnSettings.length\">\r\n              {{emptyText | translate}}\r\n            </td>\r\n          </tr>\r\n          </tbody>\r\n        </table>\r\n      </div>\r\n    </div>\r\n    <div class=\"table-footer\">\r\n      <div class=\"flex-between m-3\"\r\n           *ngIf=\"totalPages && totalElements &&  elementPerPageList &&  elementPerPageList.length !=0 && totalElements > elementPerPageList[0]\">\r\n        <div *ngIf=\"totalElementsText.length !== 0\">\r\n          {{totalElementsText | translate}}: {{rowsToDisplay.length !== 0 ? (rowsToDisplay.length + '/' + totalElements) : 0}}\r\n        </div>\r\n        <div class=\"flex mt-2 mb-2\">\r\n          <div class=\"mr-1 size\" *ngIf=\"maxSizeText.length !== 0\">{{maxSizeText | translate}}:</div>\r\n          <select [(ngModel)]=\"elementPerPage\" (change)=\"onElementPerPageChange()\">\r\n            <option *ngFor=\"let element of elementPerPageList\">{{element}}</option>\r\n          </select>\r\n          <nav>\r\n            <ul class=\"table-pagination justify-content-center\">\r\n              <li class=\"table-page-item\" [ngClass]=\"pageStart <= pagesRangeLimit ? 'disabled' : ''\">\r\n                <a class=\"table-page-link\" (click)=\"previousPages()\">\r\n                  <ng-container *ngIf=\"paginationPreviousIcon.length !== 0\">\r\n                    <img *ngIf=\"paginationPreviousIcon.includes('/')\" [src]=\"paginationPreviousIcon\">\r\n                    <i *ngIf=\"!paginationPreviousIcon.includes('/')\" class=\"{{paginationPreviousIcon}}\"></i>\r\n                  </ng-container>\r\n                  <ng-container *ngIf=\"paginationPreviousIcon.length === 0\">\r\n                    {{paginationPreviousText | translate}}\r\n                  </ng-container>\r\n                </a>\r\n              </li>\r\n              <li class=\"table-page-item\" *ngFor=\"let page of pages()\"\r\n                  [ngClass]=\"page == pageSelected ? 'active' : ''\">\r\n                <a class=\"table-page-link\" (click)=\"onPageChange(page)\">{{page}}</a>\r\n              </li>\r\n              <li class=\"table-page-item\" [ngClass]=\"pageStart + pagesRangeLimit - 1 >= totalPages ? 'disabled' : ''\">\r\n                <a class=\"table-page-link\" (click)=\"nextPages()\">\r\n                  <ng-container *ngIf=\"paginationNextIcon.length !== 0\">\r\n                    <img *ngIf=\"paginationNextIcon.includes('/')\" [src]=\"paginationNextIcon\">\r\n                    <i *ngIf=\"!paginationNextIcon.includes('/')\" class=\"{{paginationNextIcon}}\"></i>\r\n                  </ng-container>\r\n                  <ng-container *ngIf=\"paginationNextIcon.length === 0\">\r\n                    {{paginationNextText | translate}}\r\n                  </ng-container>\r\n                </a>\r\n              </li>\r\n            </ul>\r\n          </nav>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <div style=\"margin: 0; opacity: 0;height: 0;width: 0;\">Built with love by Klaus Laghom and Romeo Njinang</div>\r\n</div>\r\n", styles: [".ngx-table .flex,.ngx-table .flex-between,.ngx-table .flex-end,.ngx-table .flex-center{display:flex}.ngx-table .flex-between{justify-content:space-between}.ngx-table .flex-end{justify-content:flex-end}.ngx-table .flex-center{justify-content:center}.ngx-table .table-hover tbody tr:hover{background-color:#faf5ff}.ngx-table .table-input{width:95%;line-height:normal;padding:0 0 0 2px;font-weight:400;height:30px;margin-top:4px}.ngx-table .table-mark{background-color:#faf5ff}.ngx-table .table-border th,.ngx-table .table-border td{border:1px solid #dee2e6}.ngx-table .responsive{display:block;width:100%;overflow-x:auto}.ngx-table a{color:#1e6bb8;text-decoration:none}.ngx-table a:hover{text-decoration:underline;cursor:pointer}.ngx-table .action-button-margin{margin:0 .25rem}.ngx-table .action-button i:hover,.ngx-table .action-button img:hover,.ngx-table .action-button a:hover{opacity:.7;cursor:pointer}.ngx-table .action-button i{font-size:19px;padding:5px;color:#002e68}.ngx-table .action-button img{width:20px;height:20px;border-radius:30px;padding:6px}.ngx-table .collapse-action-button,.ngx-table .collapse-container{list-style-type:none;padding:0;margin:0}.ngx-table .collapse-action-button li .collapse-button{padding:7px;display:block}.ngx-table .collapse-action-button .collapse-container{display:none}.ngx-table .collapse-container{position:absolute;background-color:#fff;border:1px solid rgba(0,0,0,.15);border-radius:.25rem}.ngx-table .collapse-action-button li:hover .collapse-right{display:flex!important}.ngx-table .collapse-action-button li:hover .collapse-bottom{display:block!important}.ngx-table .collapse-right{max-width:20rem;overflow-x:auto;margin-top:-1.3rem}.ngx-table .collapse-bottom{max-height:20rem;overflow-y:auto;margin-top:-1.3rem}.ngx-table .p-1{padding:.25rem!important}.ngx-table .p-2{padding:.5rem!important}.ngx-table .p-3{padding:1rem!important}.ngx-table .m-1{margin:.25rem!important}.ngx-table .m-2{margin:.5rem!important}.ngx-table .m-3{margin:1rem!important}.ngx-table .mb-2{margin-bottom:.5rem!important}.ngx-table .mt-2{margin-right:.5rem!important}.ngx-table .mr-2{margin-top:.5rem!important}.ngx-table .ml-3{margin-left:1rem!important}.ngx-table .mr-1{margin-right:.25rem!important}.ngx-table .sort{cursor:pointer}.ngx-table .sort:hover{text-decoration:underline;opacity:.8}#search{max-width:50%}table thead th{position:-webkit-sticky;position:sticky;top:0;z-index:2;vertical-align:bottom;border:1px solid #dee2e6;border-bottom:2px solid #dee2e6;font-size:.875em;font-weight:700;background-color:#dee2e6;padding:.5em 1em;color:#000}table td .cell-content{max-width:250px;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;padding:.5em 1em}table td .action-button{padding:.5rem 0rem}table tr{color:#2d2d2d;font-weight:700}table{background-color:#fff;margin-bottom:0;border-collapse:collapse;width:100%}table thead tr{color:#2d2d2d;background-color:#dee0e4;font-weight:700}table th,table td{vertical-align:top;border-top:1px solid #dee2e6}td{font-weight:400;font-size:14px}.table-pagination{display:flex;padding-left:0;list-style:none;border-radius:.25rem;margin:0}.table-page-link{position:relative;display:block;padding:.25rem .5rem;margin-left:-1px;line-height:1.25;background-color:#fff;border:1px solid #dee2e6}.table-page-item .table-page-link{cursor:pointer}.table-page-item.active .table-page-link{background-color:#dee2e6;border-color:#dee2e6}.table-pagination .disabled{opacity:.5;cursor:auto}.size{min-width:100px;text-align:end;margin-top:6px}.table-footer select{margin:0 .5rem 0 .25rem}@media (max-width: 500px){.size{text-align:start}.table-footer .flex,.table-footer .flex-between{display:block!important}.table-footer nav{overflow:auto}.table-footer select{margin-bottom:1rem;margin-top:1rem}}\n"] }]
        }], ctorParameters: () => [], propDecorators: { actionButtons: [{
                type: Input
            }], collapseActionButton: [{
                type: Input
            }], columnSettings: [{
                type: Input
            }], data: [{
                type: Input
            }], emptyText: [{
                type: Input
            }], actionButtonTitle: [{
                type: Input
            }], searchText: [{
                type: Input
            }], maxSizeText: [{
                type: Input
            }], totalElementsText: [{
                type: Input
            }], paginationPreviousText: [{
                type: Input
            }], paginationNextText: [{
                type: Input
            }], paginationPreviousIcon: [{
                type: Input
            }], paginationNextIcon: [{
                type: Input
            }], displayGlobalSearchInput: [{
                type: Input
            }], colorVariationLineBreak: [{
                type: Input
            }], maxActionButtonPerRow: [{
                type: Input
            }], collapseActionButtonPosition: [{
                type: Input
            }], height: [{
                type: Input
            }], totalElements: [{
                type: Input
            }], totalPages: [{
                type: Input
            }], elementPerPage: [{
                type: Input
            }], elementPerPageList: [{
                type: Input
            }], enableColumnFiltering: [{
                type: Input
            }], enableColumnSorting: [{
                type: Input
            }], localPagination: [{
                type: Input
            }], onClickActionButton: [{
                type: Output
            }], onPageChanged: [{
                type: Output
            }], onElementPerPageChanged: [{
                type: Output
            }], onGlobalSearchRequest: [{
                type: Output
            }], onRowDisplayed: [{
                type: Output
            }] } });

class NgxAgileTableModule {
    ngxAgileTableService;
    constructor(ngxAgileTableService) {
        this.ngxAgileTableService = ngxAgileTableService;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.5", ngImport: i0, type: NgxAgileTableModule, deps: [{ token: NgxAgileTableService }], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.5", ngImport: i0, type: NgxAgileTableModule, declarations: [NgxAgileTableComponent], imports: [FormsModule,
            CommonModule,
            TranslateModule], exports: [NgxAgileTableComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.5", ngImport: i0, type: NgxAgileTableModule, providers: [
            NgxAgileTableService
        ], imports: [FormsModule,
            CommonModule,
            TranslateModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.5", ngImport: i0, type: NgxAgileTableModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgxAgileTableComponent
                    ],
                    imports: [
                        FormsModule,
                        CommonModule,
                        TranslateModule
                    ],
                    exports: [
                        NgxAgileTableComponent
                    ],
                    providers: [
                        NgxAgileTableService
                    ]
                }]
        }], ctorParameters: () => [{ type: NgxAgileTableService }] });

/*
 * Public API Surface of ngx-agile-table
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ActionButtonTable, CellData, ColumnTable, NgxAgileTableComponent, NgxAgileTableModule, RowTable };
//# sourceMappingURL=ngx-agile-table.mjs.map
